/*
 *    Copyright 2019 Frederic Thevenet
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package eu.binjr.core.data.codec.csv;

import java.time.ZonedDateTime;
import java.util.HashMap;
import java.util.Map;

/**
 * Represents a single sample/record from a csv file
 *
 * @author Frederic Thevenet
 */
public class DataSample {
    private final ZonedDateTime timeStamp;
    private final Map<String, Double> cells;

    /**
     * Initializes a new instance of the {@link DataSample} class.
     *
     * @param timeStamp the time stamp for the sample.
     */
    public DataSample(ZonedDateTime timeStamp) {
        this.timeStamp = timeStamp;
        this.cells = new HashMap<>();
    }

    /**
     * Returns the time stamp for the sample.
     *
     * @return time stamp for the sample.
     */
    public ZonedDateTime getTimeStamp() {
        return timeStamp;
    }

    /**
     * Returns a map of cells for the sample
     *
     * @return a map of cells for the sample
     */
    public Map<String, Double> getCells() {
        return cells;
    }
}
